@@ -5,7 +5,7 @@ use Module::Install::Base;
 
 use vars qw{$VERSION $ISCORE @ISA};
 BEGIN {
-	$VERSION = '0.65';
+	$VERSION = '0.68';
 	$ISCORE  = 1;
 	@ISA     = qw{Module::Install::Base};
 }
@@ -80,7 +80,7 @@ F<MANIFEST>, or possibly those not in F<MANIFEST.SKIP>.
 
 Audrey Tang E<lt>autrijus@autrijus.orgE<gt>
 
-Adam Kennedy E<lt>cpan@ali.asE<gt>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
@@ -88,7 +88,7 @@ L<Module::Install>, L<File::ShareDir>
 
 =head1 COPYRIGHT
 
-Copyright 2006 Audrey Tang, Adam Kennedy. All rights reserved.
+Copyright 2006 Audrey Tang, Adam Kennedy.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
